-------------------------------------------------------------------------------
-- system.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library UNISIM;
use UNISIM.VCOMPONENTS.ALL;

entity system is
  port (
    PB_A : out std_logic_vector(19 downto 0);
    PB_D : inout std_logic_vector(15 downto 0);
    PB_LB_N : out std_logic;
    PB_UB_N : out std_logic;
    PB_WE_N : out std_logic;
    PB_OE_N : out std_logic;
    RAM_CE_N : out std_logic;
    ETHERNET_CS_N : out std_logic;
    ETHERNET_RDY : in std_logic;
    ETHERNET_IREQ : in std_logic;
    ETHERNET_IOCS16_N : in std_logic;
    VIDOUT_CLK : out std_logic;
    VIDOUT_HSYNC_N : out std_logic;
    VIDOUT_VSYNC_N : out std_logic;
    VIDOUT_BLANK_N : out std_logic;
    VIDOUT_RCR : out std_logic_vector(9 downto 0);
    VIDOUT_GY : out std_logic_vector(9 downto 0);
    VIDOUT_BCB : out std_logic_vector(9 downto 0);
    FPGA_CLK1 : in std_logic;
    RS232_TD : out std_logic;
    RS232_RD : in std_logic;
    AU_CSN_N : out std_logic;
    AU_BCLK : out std_logic;
    AU_MCLK : out std_logic;
    AU_LRCK : out std_logic;
    AU_SDTI : out std_logic;
    AU_SDTO0 : in std_logic
  );
end system;

architecture STRUCTURE of system is

  attribute box_type : STRING;

  component mymicroblaze_wrapper is
    port (
      CLK : in std_logic;
      RESET : in std_logic;
      INTERRUPT : in std_logic;
      DEBUG_RST : in std_logic;
      EXT_BRK : in std_logic;
      EXT_NM_BRK : in std_logic;
      DBG_STOP : in std_logic;
      INSTR : in std_logic_vector(0 to 31);
      IREADY : in std_logic;
      INSTR_ADDR : out std_logic_vector(0 to 31);
      IFETCH : out std_logic;
      I_AS : out std_logic;
      DATA_READ : in std_logic_vector(0 to 31);
      DREADY : in std_logic;
      DATA_WRITE : out std_logic_vector(0 to 31);
      DATA_ADDR : out std_logic_vector(0 to 31);
      D_AS : out std_logic;
      READ_STROBE : out std_logic;
      WRITE_STROBE : out std_logic;
      BYTE_ENABLE : out std_logic_vector(0 to 3);
      DM_ABUS : out std_logic_vector(0 to 31);
      DM_BE : out std_logic_vector(0 to 3);
      DM_BUSLOCK : out std_logic;
      DM_DBUS : out std_logic_vector(0 to 31);
      DM_REQUEST : out std_logic;
      DM_RNW : out std_logic;
      DM_SELECT : out std_logic;
      DM_SEQADDR : out std_logic;
      DOPB_DBUS : in std_logic_vector(0 to 31);
      DOPB_ERRACK : in std_logic;
      DOPB_MGRANT : in std_logic;
      DOPB_RETRY : in std_logic;
      DOPB_TIMEOUT : in std_logic;
      DOPB_XFERACK : in std_logic;
      IM_ABUS : out std_logic_vector(0 to 31);
      IM_BE : out std_logic_vector(0 to 3);
      IM_BUSLOCK : out std_logic;
      IM_DBUS : out std_logic_vector(0 to 31);
      IM_REQUEST : out std_logic;
      IM_RNW : out std_logic;
      IM_SELECT : out std_logic;
      IM_SEQADDR : out std_logic;
      IOPB_DBUS : in std_logic_vector(0 to 31);
      IOPB_ERRACK : in std_logic;
      IOPB_MGRANT : in std_logic;
      IOPB_RETRY : in std_logic;
      IOPB_TIMEOUT : in std_logic;
      IOPB_XFERACK : in std_logic;
      DBG_CLK : in std_logic;
      DBG_TDI : in std_logic;
      DBG_TDO : out std_logic;
      DBG_REG_EN : in std_logic_vector(0 to 4);
      DBG_CAPTURE : in std_logic;
      DBG_UPDATE : in std_logic;
      VALID_INSTR : out std_logic;
      PC_EX : out std_logic_vector(0 to 31);
      REG_WRITE : out std_logic;
      REG_ADDR : out std_logic_vector(0 to 4);
      MSR_REG : out std_logic_vector(0 to 7);
      NEW_REG_VALUE : out std_logic_vector(0 to 31);
      PIPE_RUNNING : out std_logic;
      INTERRUPT_TAKEN : out std_logic;
      JUMP_TAKEN : out std_logic;
      PREFETCH_ADDR : out std_logic_vector(0 to 3);
      MB_Halted : out std_logic;
      FSL0_S_CLK : out std_logic;
      FSL0_S_READ : out std_logic;
      FSL0_S_DATA : in std_logic_vector(0 to 31);
      FSL0_S_CONTROL : in std_logic;
      FSL0_S_EXISTS : in std_logic;
      FSL0_M_CLK : out std_logic;
      FSL0_M_WRITE : out std_logic;
      FSL0_M_DATA : out std_logic_vector(0 to 31);
      FSL0_M_CONTROL : out std_logic;
      FSL0_M_FULL : in std_logic;
      FSL1_S_CLK : out std_logic;
      FSL1_S_READ : out std_logic;
      FSL1_S_DATA : in std_logic_vector(0 to 31);
      FSL1_S_CONTROL : in std_logic;
      FSL1_S_EXISTS : in std_logic;
      FSL1_M_CLK : out std_logic;
      FSL1_M_WRITE : out std_logic;
      FSL1_M_DATA : out std_logic_vector(0 to 31);
      FSL1_M_CONTROL : out std_logic;
      FSL1_M_FULL : in std_logic;
      FSL2_S_CLK : out std_logic;
      FSL2_S_READ : out std_logic;
      FSL2_S_DATA : in std_logic_vector(0 to 31);
      FSL2_S_CONTROL : in std_logic;
      FSL2_S_EXISTS : in std_logic;
      FSL2_M_CLK : out std_logic;
      FSL2_M_WRITE : out std_logic;
      FSL2_M_DATA : out std_logic_vector(0 to 31);
      FSL2_M_CONTROL : out std_logic;
      FSL2_M_FULL : in std_logic;
      FSL3_S_CLK : out std_logic;
      FSL3_S_READ : out std_logic;
      FSL3_S_DATA : in std_logic_vector(0 to 31);
      FSL3_S_CONTROL : in std_logic;
      FSL3_S_EXISTS : in std_logic;
      FSL3_M_CLK : out std_logic;
      FSL3_M_WRITE : out std_logic;
      FSL3_M_DATA : out std_logic_vector(0 to 31);
      FSL3_M_CONTROL : out std_logic;
      FSL3_M_FULL : in std_logic;
      FSL4_S_CLK : out std_logic;
      FSL4_S_READ : out std_logic;
      FSL4_S_DATA : in std_logic_vector(0 to 31);
      FSL4_S_CONTROL : in std_logic;
      FSL4_S_EXISTS : in std_logic;
      FSL4_M_CLK : out std_logic;
      FSL4_M_WRITE : out std_logic;
      FSL4_M_DATA : out std_logic_vector(0 to 31);
      FSL4_M_CONTROL : out std_logic;
      FSL4_M_FULL : in std_logic;
      FSL5_S_CLK : out std_logic;
      FSL5_S_READ : out std_logic;
      FSL5_S_DATA : in std_logic_vector(0 to 31);
      FSL5_S_CONTROL : in std_logic;
      FSL5_S_EXISTS : in std_logic;
      FSL5_M_CLK : out std_logic;
      FSL5_M_WRITE : out std_logic;
      FSL5_M_DATA : out std_logic_vector(0 to 31);
      FSL5_M_CONTROL : out std_logic;
      FSL5_M_FULL : in std_logic;
      FSL6_S_CLK : out std_logic;
      FSL6_S_READ : out std_logic;
      FSL6_S_DATA : in std_logic_vector(0 to 31);
      FSL6_S_CONTROL : in std_logic;
      FSL6_S_EXISTS : in std_logic;
      FSL6_M_CLK : out std_logic;
      FSL6_M_WRITE : out std_logic;
      FSL6_M_DATA : out std_logic_vector(0 to 31);
      FSL6_M_CONTROL : out std_logic;
      FSL6_M_FULL : in std_logic;
      FSL7_S_CLK : out std_logic;
      FSL7_S_READ : out std_logic;
      FSL7_S_DATA : in std_logic_vector(0 to 31);
      FSL7_S_CONTROL : in std_logic;
      FSL7_S_EXISTS : in std_logic;
      FSL7_M_CLK : out std_logic;
      FSL7_M_WRITE : out std_logic;
      FSL7_M_DATA : out std_logic_vector(0 to 31);
      FSL7_M_CONTROL : out std_logic;
      FSL7_M_FULL : in std_logic
    );
  end component;

  attribute box_type of mymicroblaze_wrapper: component is "black_box";

  component intc_wrapper is
    port (
      OPB_Clk : in std_logic;
      Intr : in std_logic_vector(0 downto 0);
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      IntC_DBus : out std_logic_vector(0 to 31);
      IntC_errAck : out std_logic;
      IntC_retry : out std_logic;
      IntC_toutSup : out std_logic;
      IntC_xferAck : out std_logic;
      Irq : out std_logic
    );
  end component;

  attribute box_type of intc_wrapper: component is "black_box";

  component bram_wrapper is
    port (
      BRAM_Rst_A : in std_logic;
      BRAM_Clk_A : in std_logic;
      BRAM_EN_A : in std_logic;
      BRAM_WEN_A : in std_logic_vector(0 to 3);
      BRAM_Addr_A : in std_logic_vector(0 to 31);
      BRAM_Din_A : out std_logic_vector(0 to 31);
      BRAM_Dout_A : in std_logic_vector(0 to 31);
      BRAM_Rst_B : in std_logic;
      BRAM_Clk_B : in std_logic;
      BRAM_EN_B : in std_logic;
      BRAM_WEN_B : in std_logic_vector(0 to 3);
      BRAM_Addr_B : in std_logic_vector(0 to 31);
      BRAM_Din_B : out std_logic_vector(0 to 31);
      BRAM_Dout_B : in std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of bram_wrapper: component is "black_box";

  component xsb300_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      UIO_DBus : out std_logic_vector(0 to 31);
      UIO_errAck : out std_logic;
      UIO_retry : out std_logic;
      UIO_toutSup : out std_logic;
      UIO_xferAck : out std_logic;
      PB_A : out std_logic_vector(19 downto 0);
      PB_LB_N : out std_logic;
      PB_UB_N : out std_logic;
      PB_D : inout std_logic_vector(15 downto 0);
      PB_WE_N : out std_logic;
      PB_OE_N : out std_logic;
      RAM_CE_N : out std_logic;
      ETHERNET_CS_N : out std_logic;
      ETHERNET_RDY : in std_logic;
      ETHERNET_IREQ : in std_logic;
      ETHERNET_IOCS16_N : in std_logic;
      pixel_clock : in std_logic;
      io_clock : in std_logic;
      VIDOUT_CLK : out std_logic;
      VIDOUT_RCR : out std_logic_vector(9 downto 0);
      VIDOUT_GY : out std_logic_vector(9 downto 0);
      VIDOUT_BCB : out std_logic_vector(9 downto 0);
      VIDOUT_BLANK_N : out std_logic;
      VIDOUT_HSYNC_N : out std_logic;
      VIDOUT_VSYNC_N : out std_logic
    );
  end component;

  attribute box_type of xsb300_wrapper: component is "black_box";

  component ak4565_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      OPB_ABus : in std_logic_vector(31 downto 0);
      OPB_BE : in std_logic_vector(3 downto 0);
      OPB_DBus : in std_logic_vector(31 downto 0);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      UIO_DBus : out std_logic_vector(31 downto 0);
      UIO_errAck : out std_logic;
      UIO_retry : out std_logic;
      UIO_toutSup : out std_logic;
      UIO_xferAck : out std_logic;
      Interrupt : out std_logic;
      AU_CSN_N : out std_logic;
      AU_BCLK : out std_logic;
      AU_MCLK : out std_logic;
      AU_LRCK : out std_logic;
      AU_SDTI : out std_logic;
      AU_SDTO0 : in std_logic
    );
  end component;

  attribute box_type of ak4565_wrapper: component is "black_box";

  component clkgen_0_wrapper is
    port (
      FPGA_CLK1 : in std_logic;
      sys_clk : out std_logic;
      pixel_clock : out std_logic;
      fpga_reset : out std_logic;
      io_clock : out std_logic
    );
  end component;

  attribute box_type of clkgen_0_wrapper: component is "black_box";

  component lmb_data_controller_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of lmb_data_controller_wrapper: component is "black_box";

  component lmb_instruction_controller_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of lmb_instruction_controller_wrapper: component is "black_box";

  component myuart_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Interrupt : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OPB_DBus : in std_logic_vector(0 to 31);
      UART_DBus : out std_logic_vector(0 to 31);
      UART_errAck : out std_logic;
      UART_retry : out std_logic;
      UART_toutSup : out std_logic;
      UART_xferAck : out std_logic;
      RX : in std_logic;
      TX : out std_logic
    );
  end component;

  attribute box_type of myuart_wrapper: component is "black_box";

  component myopb_bus_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : out std_logic;
      SYS_Rst : in std_logic;
      Debug_SYS_Rst : in std_logic;
      WDT_Rst : in std_logic;
      M_ABus : in std_logic_vector(0 to 63);
      M_BE : in std_logic_vector(0 to 7);
      M_beXfer : in std_logic_vector(0 to 1);
      M_busLock : in std_logic_vector(0 to 1);
      M_DBus : in std_logic_vector(0 to 63);
      M_DBusEn : in std_logic_vector(0 to 1);
      M_DBusEn32_63 : in std_logic_vector(0 to 1);
      M_dwXfer : in std_logic_vector(0 to 1);
      M_fwXfer : in std_logic_vector(0 to 1);
      M_hwXfer : in std_logic_vector(0 to 1);
      M_request : in std_logic_vector(0 to 1);
      M_RNW : in std_logic_vector(0 to 1);
      M_select : in std_logic_vector(0 to 1);
      M_seqAddr : in std_logic_vector(0 to 1);
      Sl_beAck : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 127);
      Sl_DBusEn : in std_logic_vector(0 to 3);
      Sl_DBusEn32_63 : in std_logic_vector(0 to 3);
      Sl_errAck : in std_logic_vector(0 to 3);
      Sl_dwAck : in std_logic_vector(0 to 3);
      Sl_fwAck : in std_logic_vector(0 to 3);
      Sl_hwAck : in std_logic_vector(0 to 3);
      Sl_retry : in std_logic_vector(0 to 3);
      Sl_toutSup : in std_logic_vector(0 to 3);
      Sl_xferAck : in std_logic_vector(0 to 3);
      OPB_MRequest : out std_logic_vector(0 to 1);
      OPB_ABus : out std_logic_vector(0 to 31);
      OPB_BE : out std_logic_vector(0 to 3);
      OPB_beXfer : out std_logic;
      OPB_beAck : out std_logic;
      OPB_busLock : out std_logic;
      OPB_rdDBus : out std_logic_vector(0 to 31);
      OPB_wrDBus : out std_logic_vector(0 to 31);
      OPB_DBus : out std_logic_vector(0 to 31);
      OPB_errAck : out std_logic;
      OPB_dwAck : out std_logic;
      OPB_dwXfer : out std_logic;
      OPB_fwAck : out std_logic;
      OPB_fwXfer : out std_logic;
      OPB_hwAck : out std_logic;
      OPB_hwXfer : out std_logic;
      OPB_MGrant : out std_logic_vector(0 to 1);
      OPB_pendReq : out std_logic_vector(0 to 1);
      OPB_retry : out std_logic;
      OPB_RNW : out std_logic;
      OPB_select : out std_logic;
      OPB_seqAddr : out std_logic;
      OPB_timeout : out std_logic;
      OPB_toutSup : out std_logic;
      OPB_xferAck : out std_logic
    );
  end component;

  attribute box_type of myopb_bus_wrapper: component is "black_box";

  component d_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of d_lmb_wrapper: component is "black_box";

  component i_lmb_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of i_lmb_wrapper: component is "black_box";

  component IBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  component OBUF is
    port (
      I : in std_logic;
      O : out std_logic
    );
  end component;

  -- Internal signals

  signal AU_BCLK_OBUF : std_logic;
  signal AU_CSN_N_OBUF : std_logic;
  signal AU_LRCK_OBUF : std_logic;
  signal AU_MCLK_OBUF : std_logic;
  signal AU_SDTI_OBUF : std_logic;
  signal AU_SDTO0_IBUF : std_logic;
  signal ETHERNET_IOCS16_N_IBUF : std_logic;
  signal ETHERNET_IREQ_IBUF : std_logic;
  signal ETHERNET_RDY_IBUF : std_logic;
  signal RS232_RD_IBUF : std_logic;
  signal RS232_TD_OBUF : std_logic;
  signal VIDOUT_BCB_OBUF : std_logic_vector(9 downto 0);
  signal VIDOUT_BLANK_N_OBUF : std_logic;
  signal VIDOUT_GY_OBUF : std_logic_vector(9 downto 0);
  signal VIDOUT_HSYNC_N_OBUF : std_logic;
  signal VIDOUT_RCR_OBUF : std_logic_vector(9 downto 0);
  signal VIDOUT_VSYNC_N_OBUF : std_logic;
  signal audio_intr : std_logic_vector(0 downto 0);
  signal conn_0_BRAM_Addr : std_logic_vector(0 to 31);
  signal conn_0_BRAM_Clk : std_logic;
  signal conn_0_BRAM_Din : std_logic_vector(0 to 31);
  signal conn_0_BRAM_Dout : std_logic_vector(0 to 31);
  signal conn_0_BRAM_EN : std_logic;
  signal conn_0_BRAM_Rst : std_logic;
  signal conn_0_BRAM_WEN : std_logic_vector(0 to 3);
  signal conn_1_BRAM_Addr : std_logic_vector(0 to 31);
  signal conn_1_BRAM_Clk : std_logic;
  signal conn_1_BRAM_Din : std_logic_vector(0 to 31);
  signal conn_1_BRAM_Dout : std_logic_vector(0 to 31);
  signal conn_1_BRAM_EN : std_logic;
  signal conn_1_BRAM_Rst : std_logic;
  signal conn_1_BRAM_WEN : std_logic_vector(0 to 3);
  signal d_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_AddrStrobe : std_logic;
  signal d_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal d_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_ReadStrobe : std_logic;
  signal d_lmb_LMB_Ready : std_logic;
  signal d_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal d_lmb_LMB_WriteStrobe : std_logic;
  signal d_lmb_M_ABus : std_logic_vector(0 to 31);
  signal d_lmb_M_AddrStrobe : std_logic;
  signal d_lmb_M_BE : std_logic_vector(0 to 3);
  signal d_lmb_M_DBus : std_logic_vector(0 to 31);
  signal d_lmb_M_ReadStrobe : std_logic;
  signal d_lmb_M_WriteStrobe : std_logic;
  signal d_lmb_OPB_Rst : std_logic;
  signal d_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal d_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal fpga_reset : std_logic;
  signal i_lmb_LMB_ABus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_AddrStrobe : std_logic;
  signal i_lmb_LMB_BE : std_logic_vector(0 to 3);
  signal i_lmb_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_ReadStrobe : std_logic;
  signal i_lmb_LMB_Ready : std_logic;
  signal i_lmb_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal i_lmb_LMB_WriteStrobe : std_logic;
  signal i_lmb_M_ABus : std_logic_vector(0 to 31);
  signal i_lmb_M_AddrStrobe : std_logic;
  signal i_lmb_M_ReadStrobe : std_logic;
  signal i_lmb_OPB_Rst : std_logic;
  signal i_lmb_Sl_DBus : std_logic_vector(0 to 31);
  signal i_lmb_Sl_Ready : std_logic_vector(0 to 0);
  signal intr : std_logic;
  signal io_clock : std_logic;
  signal myopb_bus_M_ABus : std_logic_vector(0 to 63);
  signal myopb_bus_M_BE : std_logic_vector(0 to 7);
  signal myopb_bus_M_DBus : std_logic_vector(0 to 63);
  signal myopb_bus_M_RNW : std_logic_vector(0 to 1);
  signal myopb_bus_M_busLock : std_logic_vector(0 to 1);
  signal myopb_bus_M_request : std_logic_vector(0 to 1);
  signal myopb_bus_M_select : std_logic_vector(0 to 1);
  signal myopb_bus_M_seqAddr : std_logic_vector(0 to 1);
  signal myopb_bus_OPB_ABus : std_logic_vector(0 to 31);
  signal myopb_bus_OPB_BE : std_logic_vector(0 to 3);
  signal myopb_bus_OPB_DBus : std_logic_vector(0 to 31);
  signal myopb_bus_OPB_MGrant : std_logic_vector(0 to 1);
  signal myopb_bus_OPB_RNW : std_logic;
  signal myopb_bus_OPB_Rst : std_logic;
  signal myopb_bus_OPB_errAck : std_logic;
  signal myopb_bus_OPB_retry : std_logic;
  signal myopb_bus_OPB_select : std_logic;
  signal myopb_bus_OPB_seqAddr : std_logic;
  signal myopb_bus_OPB_timeout : std_logic;
  signal myopb_bus_OPB_xferAck : std_logic;
  signal myopb_bus_Sl_DBus : std_logic_vector(0 to 127);
  signal myopb_bus_Sl_errAck : std_logic_vector(0 to 3);
  signal myopb_bus_Sl_retry : std_logic_vector(0 to 3);
  signal myopb_bus_Sl_toutSup : std_logic_vector(0 to 3);
  signal myopb_bus_Sl_xferAck : std_logic_vector(0 to 3);
  signal net_gnd0 : std_logic;
  signal net_gnd2 : std_logic_vector(0 to 1);
  signal net_gnd32 : std_logic_vector(0 to 31);
  signal net_gnd4 : std_logic_vector(0 to 3);
  signal net_gnd5 : std_logic_vector(0 to 4);
  signal net_vcc2 : std_logic_vector(0 to 1);
  signal net_vcc4 : std_logic_vector(0 to 3);
  signal pixel_clock : std_logic;
  signal sys_clk : std_logic;

begin

  -- Internal assignments

  net_gnd0 <= '0';
  net_gnd2(0 to 1) <= B"00";
  net_gnd32(0 to 31) <= B"00000000000000000000000000000000";
  net_gnd4(0 to 3) <= B"0000";
  net_gnd5(0 to 4) <= B"00000";
  net_vcc2(0 to 1) <= B"11";
  net_vcc4(0 to 3) <= B"1111";

  mymicroblaze : mymicroblaze_wrapper
    port map (
      CLK => sys_clk,
      RESET => fpga_reset,
      INTERRUPT => intr,
      DEBUG_RST => net_gnd0,
      EXT_BRK => net_gnd0,
      EXT_NM_BRK => net_gnd0,
      DBG_STOP => net_gnd0,
      INSTR => i_lmb_LMB_ReadDBus,
      IREADY => i_lmb_LMB_Ready,
      INSTR_ADDR => i_lmb_M_ABus,
      IFETCH => i_lmb_M_ReadStrobe,
      I_AS => i_lmb_M_AddrStrobe,
      DATA_READ => d_lmb_LMB_ReadDBus,
      DREADY => d_lmb_LMB_Ready,
      DATA_WRITE => d_lmb_M_DBus,
      DATA_ADDR => d_lmb_M_ABus,
      D_AS => d_lmb_M_AddrStrobe,
      READ_STROBE => d_lmb_M_ReadStrobe,
      WRITE_STROBE => d_lmb_M_WriteStrobe,
      BYTE_ENABLE => d_lmb_M_BE,
      DM_ABUS => myopb_bus_M_ABus(0 to 31),
      DM_BE => myopb_bus_M_BE(0 to 3),
      DM_BUSLOCK => myopb_bus_M_busLock(0),
      DM_DBUS => myopb_bus_M_DBus(0 to 31),
      DM_REQUEST => myopb_bus_M_request(0),
      DM_RNW => myopb_bus_M_RNW(0),
      DM_SELECT => myopb_bus_M_select(0),
      DM_SEQADDR => myopb_bus_M_seqAddr(0),
      DOPB_DBUS => myopb_bus_OPB_DBus,
      DOPB_ERRACK => myopb_bus_OPB_errAck,
      DOPB_MGRANT => myopb_bus_OPB_MGrant(0),
      DOPB_RETRY => myopb_bus_OPB_retry,
      DOPB_TIMEOUT => myopb_bus_OPB_timeout,
      DOPB_XFERACK => myopb_bus_OPB_xferAck,
      IM_ABUS => myopb_bus_M_ABus(32 to 63),
      IM_BE => myopb_bus_M_BE(4 to 7),
      IM_BUSLOCK => myopb_bus_M_busLock(1),
      IM_DBUS => myopb_bus_M_DBus(32 to 63),
      IM_REQUEST => myopb_bus_M_request(1),
      IM_RNW => myopb_bus_M_RNW(1),
      IM_SELECT => myopb_bus_M_select(1),
      IM_SEQADDR => myopb_bus_M_seqAddr(1),
      IOPB_DBUS => myopb_bus_OPB_DBus,
      IOPB_ERRACK => myopb_bus_OPB_errAck,
      IOPB_MGRANT => myopb_bus_OPB_MGrant(1),
      IOPB_RETRY => myopb_bus_OPB_retry,
      IOPB_TIMEOUT => myopb_bus_OPB_timeout,
      IOPB_XFERACK => myopb_bus_OPB_xferAck,
      DBG_CLK => net_gnd0,
      DBG_TDI => net_gnd0,
      DBG_TDO => open,
      DBG_REG_EN => net_gnd5,
      DBG_CAPTURE => net_gnd0,
      DBG_UPDATE => net_gnd0,
      VALID_INSTR => open,
      PC_EX => open,
      REG_WRITE => open,
      REG_ADDR => open,
      MSR_REG => open,
      NEW_REG_VALUE => open,
      PIPE_RUNNING => open,
      INTERRUPT_TAKEN => open,
      JUMP_TAKEN => open,
      PREFETCH_ADDR => open,
      MB_Halted => open,
      FSL0_S_CLK => open,
      FSL0_S_READ => open,
      FSL0_S_DATA => net_gnd32,
      FSL0_S_CONTROL => net_gnd0,
      FSL0_S_EXISTS => net_gnd0,
      FSL0_M_CLK => open,
      FSL0_M_WRITE => open,
      FSL0_M_DATA => open,
      FSL0_M_CONTROL => open,
      FSL0_M_FULL => net_gnd0,
      FSL1_S_CLK => open,
      FSL1_S_READ => open,
      FSL1_S_DATA => net_gnd32,
      FSL1_S_CONTROL => net_gnd0,
      FSL1_S_EXISTS => net_gnd0,
      FSL1_M_CLK => open,
      FSL1_M_WRITE => open,
      FSL1_M_DATA => open,
      FSL1_M_CONTROL => open,
      FSL1_M_FULL => net_gnd0,
      FSL2_S_CLK => open,
      FSL2_S_READ => open,
      FSL2_S_DATA => net_gnd32,
      FSL2_S_CONTROL => net_gnd0,
      FSL2_S_EXISTS => net_gnd0,
      FSL2_M_CLK => open,
      FSL2_M_WRITE => open,
      FSL2_M_DATA => open,
      FSL2_M_CONTROL => open,
      FSL2_M_FULL => net_gnd0,
      FSL3_S_CLK => open,
      FSL3_S_READ => open,
      FSL3_S_DATA => net_gnd32,
      FSL3_S_CONTROL => net_gnd0,
      FSL3_S_EXISTS => net_gnd0,
      FSL3_M_CLK => open,
      FSL3_M_WRITE => open,
      FSL3_M_DATA => open,
      FSL3_M_CONTROL => open,
      FSL3_M_FULL => net_gnd0,
      FSL4_S_CLK => open,
      FSL4_S_READ => open,
      FSL4_S_DATA => net_gnd32,
      FSL4_S_CONTROL => net_gnd0,
      FSL4_S_EXISTS => net_gnd0,
      FSL4_M_CLK => open,
      FSL4_M_WRITE => open,
      FSL4_M_DATA => open,
      FSL4_M_CONTROL => open,
      FSL4_M_FULL => net_gnd0,
      FSL5_S_CLK => open,
      FSL5_S_READ => open,
      FSL5_S_DATA => net_gnd32,
      FSL5_S_CONTROL => net_gnd0,
      FSL5_S_EXISTS => net_gnd0,
      FSL5_M_CLK => open,
      FSL5_M_WRITE => open,
      FSL5_M_DATA => open,
      FSL5_M_CONTROL => open,
      FSL5_M_FULL => net_gnd0,
      FSL6_S_CLK => open,
      FSL6_S_READ => open,
      FSL6_S_DATA => net_gnd32,
      FSL6_S_CONTROL => net_gnd0,
      FSL6_S_EXISTS => net_gnd0,
      FSL6_M_CLK => open,
      FSL6_M_WRITE => open,
      FSL6_M_DATA => open,
      FSL6_M_CONTROL => open,
      FSL6_M_FULL => net_gnd0,
      FSL7_S_CLK => open,
      FSL7_S_READ => open,
      FSL7_S_DATA => net_gnd32,
      FSL7_S_CONTROL => net_gnd0,
      FSL7_S_EXISTS => net_gnd0,
      FSL7_M_CLK => open,
      FSL7_M_WRITE => open,
      FSL7_M_DATA => open,
      FSL7_M_CONTROL => open,
      FSL7_M_FULL => net_gnd0
    );

  intc : intc_wrapper
    port map (
      OPB_Clk => sys_clk,
      Intr => audio_intr(0 downto 0),
      OPB_Rst => myopb_bus_OPB_Rst,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      OPB_DBus => myopb_bus_OPB_DBus,
      IntC_DBus => myopb_bus_Sl_DBus(0 to 31),
      IntC_errAck => myopb_bus_Sl_errAck(0),
      IntC_retry => myopb_bus_Sl_retry(0),
      IntC_toutSup => myopb_bus_Sl_toutSup(0),
      IntC_xferAck => myopb_bus_Sl_xferAck(0),
      Irq => intr
    );

  bram : bram_wrapper
    port map (
      BRAM_Rst_A => conn_0_BRAM_Rst,
      BRAM_Clk_A => conn_0_BRAM_Clk,
      BRAM_EN_A => conn_0_BRAM_EN,
      BRAM_WEN_A => conn_0_BRAM_WEN,
      BRAM_Addr_A => conn_0_BRAM_Addr,
      BRAM_Din_A => conn_0_BRAM_Din,
      BRAM_Dout_A => conn_0_BRAM_Dout,
      BRAM_Rst_B => conn_1_BRAM_Rst,
      BRAM_Clk_B => conn_1_BRAM_Clk,
      BRAM_EN_B => conn_1_BRAM_EN,
      BRAM_WEN_B => conn_1_BRAM_WEN,
      BRAM_Addr_B => conn_1_BRAM_Addr,
      BRAM_Din_B => conn_1_BRAM_Din,
      BRAM_Dout_B => conn_1_BRAM_Dout
    );

  xsb300 : xsb300_wrapper
    port map (
      OPB_Clk => sys_clk,
      OPB_Rst => myopb_bus_OPB_Rst,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      UIO_DBus => myopb_bus_Sl_DBus(32 to 63),
      UIO_errAck => myopb_bus_Sl_errAck(1),
      UIO_retry => myopb_bus_Sl_retry(1),
      UIO_toutSup => myopb_bus_Sl_toutSup(1),
      UIO_xferAck => myopb_bus_Sl_xferAck(1),
      PB_A => PB_A,
      PB_LB_N => PB_LB_N,
      PB_UB_N => PB_UB_N,
      PB_D => PB_D,
      PB_WE_N => PB_WE_N,
      PB_OE_N => PB_OE_N,
      RAM_CE_N => RAM_CE_N,
      ETHERNET_CS_N => ETHERNET_CS_N,
      ETHERNET_RDY => ETHERNET_RDY_IBUF,
      ETHERNET_IREQ => ETHERNET_IREQ_IBUF,
      ETHERNET_IOCS16_N => ETHERNET_IOCS16_N_IBUF,
      pixel_clock => pixel_clock,
      io_clock => io_clock,
      VIDOUT_CLK => VIDOUT_CLK,
      VIDOUT_RCR => VIDOUT_RCR_OBUF,
      VIDOUT_GY => VIDOUT_GY_OBUF,
      VIDOUT_BCB => VIDOUT_BCB_OBUF,
      VIDOUT_BLANK_N => VIDOUT_BLANK_N_OBUF,
      VIDOUT_HSYNC_N => VIDOUT_HSYNC_N_OBUF,
      VIDOUT_VSYNC_N => VIDOUT_VSYNC_N_OBUF
    );

  ak4565 : ak4565_wrapper
    port map (
      OPB_Clk => sys_clk,
      OPB_Rst => myopb_bus_OPB_Rst,
      OPB_ABus => myopb_bus_OPB_ABus(0 to 31),
      OPB_BE => myopb_bus_OPB_BE(0 to 3),
      OPB_DBus => myopb_bus_OPB_DBus(0 to 31),
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      UIO_DBus => myopb_bus_Sl_DBus(64 to 95),
      UIO_errAck => myopb_bus_Sl_errAck(2),
      UIO_retry => myopb_bus_Sl_retry(2),
      UIO_toutSup => myopb_bus_Sl_toutSup(2),
      UIO_xferAck => myopb_bus_Sl_xferAck(2),
      Interrupt => audio_intr(0),
      AU_CSN_N => AU_CSN_N_OBUF,
      AU_BCLK => AU_BCLK_OBUF,
      AU_MCLK => AU_MCLK_OBUF,
      AU_LRCK => AU_LRCK_OBUF,
      AU_SDTI => AU_SDTI_OBUF,
      AU_SDTO0 => AU_SDTO0_IBUF
    );

  clkgen_0 : clkgen_0_wrapper
    port map (
      FPGA_CLK1 => FPGA_CLK1,
      sys_clk => sys_clk,
      pixel_clock => pixel_clock,
      fpga_reset => fpga_reset,
      io_clock => io_clock
    );

  lmb_data_controller : lmb_data_controller_wrapper
    port map (
      LMB_Clk => sys_clk,
      LMB_Rst => d_lmb_OPB_Rst,
      LMB_ABus => d_lmb_LMB_ABus,
      LMB_WriteDBus => d_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
      LMB_BE => d_lmb_LMB_BE,
      Sl_DBus => d_lmb_Sl_DBus,
      Sl_Ready => d_lmb_Sl_Ready(0),
      BRAM_Rst_A => conn_0_BRAM_Rst,
      BRAM_Clk_A => conn_0_BRAM_Clk,
      BRAM_EN_A => conn_0_BRAM_EN,
      BRAM_WEN_A => conn_0_BRAM_WEN,
      BRAM_Addr_A => conn_0_BRAM_Addr,
      BRAM_Din_A => conn_0_BRAM_Din,
      BRAM_Dout_A => conn_0_BRAM_Dout
    );

  lmb_instruction_controller : lmb_instruction_controller_wrapper
    port map (
      LMB_Clk => sys_clk,
      LMB_Rst => i_lmb_OPB_Rst,
      LMB_ABus => i_lmb_LMB_ABus,
      LMB_WriteDBus => i_lmb_LMB_WriteDBus,
      LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
      LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
      LMB_BE => i_lmb_LMB_BE,
      Sl_DBus => i_lmb_Sl_DBus,
      Sl_Ready => i_lmb_Sl_Ready(0),
      BRAM_Rst_A => conn_1_BRAM_Rst,
      BRAM_Clk_A => conn_1_BRAM_Clk,
      BRAM_EN_A => conn_1_BRAM_EN,
      BRAM_WEN_A => conn_1_BRAM_WEN,
      BRAM_Addr_A => conn_1_BRAM_Addr,
      BRAM_Din_A => conn_1_BRAM_Din,
      BRAM_Dout_A => conn_1_BRAM_Dout
    );

  myuart : myuart_wrapper
    port map (
      OPB_Clk => sys_clk,
      OPB_Rst => myopb_bus_OPB_Rst,
      Interrupt => open,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      OPB_DBus => myopb_bus_OPB_DBus,
      UART_DBus => myopb_bus_Sl_DBus(96 to 127),
      UART_errAck => myopb_bus_Sl_errAck(3),
      UART_retry => myopb_bus_Sl_retry(3),
      UART_toutSup => myopb_bus_Sl_toutSup(3),
      UART_xferAck => myopb_bus_Sl_xferAck(3),
      RX => RS232_RD_IBUF,
      TX => RS232_TD_OBUF
    );

  myopb_bus : myopb_bus_wrapper
    port map (
      OPB_Clk => sys_clk,
      OPB_Rst => myopb_bus_OPB_Rst,
      SYS_Rst => fpga_reset,
      Debug_SYS_Rst => net_gnd0,
      WDT_Rst => net_gnd0,
      M_ABus => myopb_bus_M_ABus,
      M_BE => myopb_bus_M_BE,
      M_beXfer => net_gnd2,
      M_busLock => myopb_bus_M_busLock,
      M_DBus => myopb_bus_M_DBus,
      M_DBusEn => net_gnd2,
      M_DBusEn32_63 => net_vcc2,
      M_dwXfer => net_gnd2,
      M_fwXfer => net_gnd2,
      M_hwXfer => net_gnd2,
      M_request => myopb_bus_M_request,
      M_RNW => myopb_bus_M_RNW,
      M_select => myopb_bus_M_select,
      M_seqAddr => myopb_bus_M_seqAddr,
      Sl_beAck => net_gnd4,
      Sl_DBus => myopb_bus_Sl_DBus,
      Sl_DBusEn => net_vcc4,
      Sl_DBusEn32_63 => net_vcc4,
      Sl_errAck => myopb_bus_Sl_errAck,
      Sl_dwAck => net_gnd4,
      Sl_fwAck => net_gnd4,
      Sl_hwAck => net_gnd4,
      Sl_retry => myopb_bus_Sl_retry,
      Sl_toutSup => myopb_bus_Sl_toutSup,
      Sl_xferAck => myopb_bus_Sl_xferAck,
      OPB_MRequest => open,
      OPB_ABus => myopb_bus_OPB_ABus,
      OPB_BE => myopb_bus_OPB_BE,
      OPB_beXfer => open,
      OPB_beAck => open,
      OPB_busLock => open,
      OPB_rdDBus => open,
      OPB_wrDBus => open,
      OPB_DBus => myopb_bus_OPB_DBus,
      OPB_errAck => myopb_bus_OPB_errAck,
      OPB_dwAck => open,
      OPB_dwXfer => open,
      OPB_fwAck => open,
      OPB_fwXfer => open,
      OPB_hwAck => open,
      OPB_hwXfer => open,
      OPB_MGrant => myopb_bus_OPB_MGrant,
      OPB_pendReq => open,
      OPB_retry => myopb_bus_OPB_retry,
      OPB_RNW => myopb_bus_OPB_RNW,
      OPB_select => myopb_bus_OPB_select,
      OPB_seqAddr => myopb_bus_OPB_seqAddr,
      OPB_timeout => myopb_bus_OPB_timeout,
      OPB_toutSup => open,
      OPB_xferAck => myopb_bus_OPB_xferAck
    );

  d_lmb : d_lmb_wrapper
    port map (
      LMB_Clk => sys_clk,
      SYS_Rst => fpga_reset,
      LMB_Rst => d_lmb_OPB_Rst,
      M_ABus => d_lmb_M_ABus,
      M_ReadStrobe => d_lmb_M_ReadStrobe,
      M_WriteStrobe => d_lmb_M_WriteStrobe,
      M_AddrStrobe => d_lmb_M_AddrStrobe,
      M_DBus => d_lmb_M_DBus,
      M_BE => d_lmb_M_BE,
      Sl_DBus => d_lmb_Sl_DBus,
      Sl_Ready => d_lmb_Sl_Ready(0 to 0),
      LMB_ABus => d_lmb_LMB_ABus,
      LMB_ReadStrobe => d_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => d_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => d_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => d_lmb_LMB_ReadDBus,
      LMB_WriteDBus => d_lmb_LMB_WriteDBus,
      LMB_Ready => d_lmb_LMB_Ready,
      LMB_BE => d_lmb_LMB_BE
    );

  i_lmb : i_lmb_wrapper
    port map (
      LMB_Clk => sys_clk,
      SYS_Rst => fpga_reset,
      LMB_Rst => i_lmb_OPB_Rst,
      M_ABus => i_lmb_M_ABus,
      M_ReadStrobe => i_lmb_M_ReadStrobe,
      M_WriteStrobe => net_gnd0,
      M_AddrStrobe => i_lmb_M_AddrStrobe,
      M_DBus => net_gnd32,
      M_BE => net_gnd4,
      Sl_DBus => i_lmb_Sl_DBus,
      Sl_Ready => i_lmb_Sl_Ready(0 to 0),
      LMB_ABus => i_lmb_LMB_ABus,
      LMB_ReadStrobe => i_lmb_LMB_ReadStrobe,
      LMB_WriteStrobe => i_lmb_LMB_WriteStrobe,
      LMB_AddrStrobe => i_lmb_LMB_AddrStrobe,
      LMB_ReadDBus => i_lmb_LMB_ReadDBus,
      LMB_WriteDBus => i_lmb_LMB_WriteDBus,
      LMB_Ready => i_lmb_LMB_Ready,
      LMB_BE => i_lmb_LMB_BE
    );

  ibuf_0 : IBUF
    port map (
      I => ETHERNET_RDY,
      O => ETHERNET_RDY_IBUF
    );

  ibuf_1 : IBUF
    port map (
      I => ETHERNET_IREQ,
      O => ETHERNET_IREQ_IBUF
    );

  ibuf_2 : IBUF
    port map (
      I => ETHERNET_IOCS16_N,
      O => ETHERNET_IOCS16_N_IBUF
    );

  obuf_3 : OBUF
    port map (
      I => VIDOUT_HSYNC_N_OBUF,
      O => VIDOUT_HSYNC_N
    );

  obuf_4 : OBUF
    port map (
      I => VIDOUT_VSYNC_N_OBUF,
      O => VIDOUT_VSYNC_N
    );

  obuf_5 : OBUF
    port map (
      I => VIDOUT_BLANK_N_OBUF,
      O => VIDOUT_BLANK_N
    );

  obuf_6 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(9),
      O => VIDOUT_RCR(9)
    );

  obuf_7 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(8),
      O => VIDOUT_RCR(8)
    );

  obuf_8 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(7),
      O => VIDOUT_RCR(7)
    );

  obuf_9 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(6),
      O => VIDOUT_RCR(6)
    );

  obuf_10 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(5),
      O => VIDOUT_RCR(5)
    );

  obuf_11 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(4),
      O => VIDOUT_RCR(4)
    );

  obuf_12 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(3),
      O => VIDOUT_RCR(3)
    );

  obuf_13 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(2),
      O => VIDOUT_RCR(2)
    );

  obuf_14 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(1),
      O => VIDOUT_RCR(1)
    );

  obuf_15 : OBUF
    port map (
      I => VIDOUT_RCR_OBUF(0),
      O => VIDOUT_RCR(0)
    );

  obuf_16 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(9),
      O => VIDOUT_GY(9)
    );

  obuf_17 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(8),
      O => VIDOUT_GY(8)
    );

  obuf_18 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(7),
      O => VIDOUT_GY(7)
    );

  obuf_19 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(6),
      O => VIDOUT_GY(6)
    );

  obuf_20 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(5),
      O => VIDOUT_GY(5)
    );

  obuf_21 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(4),
      O => VIDOUT_GY(4)
    );

  obuf_22 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(3),
      O => VIDOUT_GY(3)
    );

  obuf_23 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(2),
      O => VIDOUT_GY(2)
    );

  obuf_24 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(1),
      O => VIDOUT_GY(1)
    );

  obuf_25 : OBUF
    port map (
      I => VIDOUT_GY_OBUF(0),
      O => VIDOUT_GY(0)
    );

  obuf_26 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(9),
      O => VIDOUT_BCB(9)
    );

  obuf_27 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(8),
      O => VIDOUT_BCB(8)
    );

  obuf_28 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(7),
      O => VIDOUT_BCB(7)
    );

  obuf_29 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(6),
      O => VIDOUT_BCB(6)
    );

  obuf_30 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(5),
      O => VIDOUT_BCB(5)
    );

  obuf_31 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(4),
      O => VIDOUT_BCB(4)
    );

  obuf_32 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(3),
      O => VIDOUT_BCB(3)
    );

  obuf_33 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(2),
      O => VIDOUT_BCB(2)
    );

  obuf_34 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(1),
      O => VIDOUT_BCB(1)
    );

  obuf_35 : OBUF
    port map (
      I => VIDOUT_BCB_OBUF(0),
      O => VIDOUT_BCB(0)
    );

  obuf_36 : OBUF
    port map (
      I => RS232_TD_OBUF,
      O => RS232_TD
    );

  ibuf_37 : IBUF
    port map (
      I => RS232_RD,
      O => RS232_RD_IBUF
    );

  obuf_38 : OBUF
    port map (
      I => AU_CSN_N_OBUF,
      O => AU_CSN_N
    );

  obuf_39 : OBUF
    port map (
      I => AU_BCLK_OBUF,
      O => AU_BCLK
    );

  obuf_40 : OBUF
    port map (
      I => AU_MCLK_OBUF,
      O => AU_MCLK
    );

  obuf_41 : OBUF
    port map (
      I => AU_LRCK_OBUF,
      O => AU_LRCK
    );

  obuf_42 : OBUF
    port map (
      I => AU_SDTI_OBUF,
      O => AU_SDTI
    );

  ibuf_43 : IBUF
    port map (
      I => AU_SDTO0,
      O => AU_SDTO0_IBUF
    );

end architecture STRUCTURE;

